/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is locale4j.
 *
 * The Initial Developer of the Original Code is
 * the Vermont Department of Taxes.
 * Portions created by the Initial Developer are Copyright (C) 2007
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *   Tom Cort <tom.cort@state.vt.us>
 *
 * ***** END LICENSE BLOCK ***** */
package net.sf.locale4j.bundle;

import net.sf.locale4j.storage.LocaleStore;

import java.util.Iterator;
import java.util.List;
import java.util.ListResourceBundle;
import java.util.Locale;

/**
 * Facade for default localization resource bundle.
 */
public abstract class Locale4jBundle extends ListResourceBundle {

    /**
     * Translation information.
     */
    private LocaleStore store;

    /**
     * Default Constructor.
     */
    public Locale4jBundle() {
        super();
        loadBundle();
    }

    /**
     * This method is responsible for setting up the LocaleStore object.
     * It is called from the constructor.
     */
    protected abstract void loadBundle();

    /**
     * Gets the language table for the default language.
     * @return an object array of key-value pairs.
     */
    protected Object[][] getContents() {
        return getContents(Locale.getDefault());
    }

    /**
     * Gets a translation table for a given locale.
     * @param locale language to get
     * @return an object array of key-value pairs.
     */
    protected Object[][] getContents(Locale locale) {
        List < String > keys = store.getKeys(locale);
        Object[][] map = new Object[keys.size()][2];

        Iterator < String > itr = keys.iterator();
        for (int i = 0; itr.hasNext(); i++) {
            String key   = itr.next();
            String value = store.get(locale, key);
            map[i][0] = key;
            map[i][1] = value;
        }

        return map;
    }

    /**
     * @return the store
     */
    public final LocaleStore getStore() {
        return store;
    }

    /**
     * @param newStore the store to set
     */
    public final void setStore(LocaleStore newStore) {
        this.store = newStore;
    }
}

