/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is locale4j.
 *
 * The Initial Developer of the Original Code is
 * the Vermont Department of Taxes.
 * Portions created by the Initial Developer are Copyright (C) 2007
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *   Tom Cort <tom.cort@state.vt.us>
 *
 * ***** END LICENSE BLOCK ***** */

package net.sf.locale4j.storage;

import java.util.List;
import java.util.Locale;

/**
 * An interface for classes capable of storing locale data.
 */
public interface LocaleStore {
    /**
     * Fetch a list of locales for which translations exist.
     * @return a list of locales.
     */
    List < Locale > getLocales();

    /**
     * Fetch a list of keys for the given locale.
     * @param locale the locale of the Strings the keys point to.
     * @return a list of keys
     */
    List < String > getKeys(Locale locale);

    /**
     * Fetches a string in the language specified by the locale.
     * @param locale the locale for which the String is localized.
     * @param key the key used to reference the stored String.
     * @return the localized string.
     */
    String get(Locale locale, String key);

    /**
     * Stores a string in the language specified by the locale.
     * If the string does not exist, "???" is returned.
     * @param locale the locale for which the String is localized.
     * @param key the key used to reference the stored String.
     * @param text the String to store.
     */
    void put(Locale locale, String key, String text);

    /**
     * Removes a string from the language specified by the locale.
     * @param locale the locale for which the String is localized.
     * @param key the key used to reference the stored String.
     * @return the values associated with the removed key, or null 
     *         if the key/table doesn't exist or is set to null.
     */
    Object removeKey(Locale locale, String key) throws Exception ; 
 
    /**
     * Removes and entire locale.
     * @param locale the locale to remove.
     * @return the values associated with the removed key, or null 
     *         if the key/table doesn't exist or is set to null.
     */
    Object removeLocale(Locale locale) throws Exception ;
}

